@@ -8,7 +8,7 @@ use Syntax::Keyword::Match;
 use Exporter 'import';
 our @EXPORT_OK = qw(measurement tags fields timestamp);
 
-our $VERSION = "0.1.1";
+our $VERSION = "0.1.2";
 our $TELEGRAF = $ENV{QUOTE_TELEGRAF} // 0; # Telegraf requires special quoting
 
 my $qr = qr{([,=\s])};    # Match tag and field keys, and tag values
@@ -123,6 +123,16 @@ Quote::LineProtocol - Helper module for Lineprotocol quoting
     meant to be sent over the InfluxDB lineprotocol following the rules specified
     on L<https://docs.influxdata.com/influxdb/v2/reference/syntax/line-protocol/>
 
+=head1 CONFIGURATION
+
+Telegraf requires special consideration of spaces in strings. If using this module with telegraf set the env var QUOTE_TELEGRAF before calling the script or use the following BEGIN block
+
+    BEGIN {
+      $ENV{QUOTE_TELEGRAF} = 1;
+      require Quote::LineProtocol;
+      Quote::LineProtocol->import(qw(measurement tags fields timestamp));
+    }
+
 =head1 METHODS
 
 =head2 measurement($str)
